@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_living_c =
- *   "$Id: living.c,v 1.31 1995/04/15 03:09:02 master Exp master $";
+ *   "$Id: living.c,v 1.32 1995/07/24 22:02:51 master Exp $";
  */
 
 /*
@@ -486,7 +486,7 @@ int change_abil(object *op, object *tmp) {
     else
       (*draw_info_func)(NDI_UNIQUE, 0, op,"You feel much less healthy!");
   }
-  if(tmp->stats.sp && op->type==PLAYER) {
+  if(tmp->stats.sp && op->type==PLAYER && tmp->type!=SKILL) {
     op->contr->gen_sp+=tmp->stats.sp*flag;
     if(flag*tmp->stats.sp>0)
       (*draw_info_func)(NDI_UNIQUE, 0, op,"You feel one with the powers of magic!");
@@ -804,6 +804,48 @@ void fix_player(object *op) {
           added_speed+=(float)tmp->stats.exp;
       }
       switch(tmp->type) {
+
+      case SKILL: 		/* skills modifying the character -b.t. */ 
+	if(op->chosen_skill==tmp) { 
+
+	/* for all skills and skill granting objects */ 
+	/* -these bonuses come from the object (not the skill per se) */
+
+	  op->stats.wc-=tmp->stats.wc; 
+
+	  if(!QUERY_FLAG(op,FLAG_READY_WEAPON)) 
+            weapon_speed = (int) WEAPON_SPEED(tmp);
+
+          if(tmp->armour)
+            op->armour+=((100-op->armour)*tmp->armour)/100;
+
+	  if(tmp->stats.dam>0) { 
+	    op->stats.dam=op->arch->clone.stats.dam+dam_bonus[op->stats.Str];
+	    op->stats.dam+=tmp->stats.dam;
+	  }
+
+          if(tmp->slaying!=NULL)
+            add_refcount(op->slaying = tmp->slaying);
+
+	  if(tmp->stats.ac&&tmp->stats.ac+tmp->magic>0)
+            op->stats.ac-=tmp->stats.ac+tmp->magic;
+
+	/* now for the dam/speed modifiers of the skill that the object
+	 * allows the user to practice. */  
+
+	   if(tmp->invisible) 	
+		break;
+	   else {  
+		object *tmp2;
+		tmp2 = arch_to_object(tmp->arch);
+	   	if(!QUERY_FLAG(op,FLAG_READY_WEAPON)) 
+			weapon_speed = (int) WEAPON_SPEED(tmp2);
+           	if(tmp2->stats.dam>0)
+              		op->stats.dam+=tmp2->stats.dam*(1 + (op->level/9));
+	   }
+	}
+	break;
+
       case SHIELD:
 #ifdef SPELL_ENCUMBRANCE
 	if(op->type==PLAYER) op->contr->encumbrance+=(int)tmp->weight/2000;
