@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_object_c =
- *   "$Id: loader.c,v 1.29 1995/04/15 03:13:14 master Exp master $";
+ *   "$Id: loader.c,v 1.30 1995/07/24 22:03:20 master Exp $";
  */
 
 /*
@@ -71,6 +71,7 @@ static char *variable_const[NR_OF_VARIABLES] = {
   "can_steal","been_applied","title","has_ready_rod","can_use_rod",
   "has_ready_horn","can_use_horn","expmul",
   "unique","make_invisible","inv_locked",
+  "is_wooded","is_hilly","has_ready_skill","has_ready_weapon", 
 #ifdef NPC_PROG
   "npc_status","npc_program",
 #endif
@@ -127,7 +128,9 @@ int flag_links[NUM_FLAGS+1][2] ={
 {FLAG_BEEN_APPLIED, V_BEEN_APPLIED},  {FLAG_READY_ROD, V_HAS_READY_ROD},
 {FLAG_USE_ROD, V_CAN_USE_ROD}, {FLAG_READY_HORN, V_HAS_READY_HORN}, 
 {FLAG_USE_HORN, V_CAN_USE_HORN},{FLAG_MAKE_INVIS,V_MAKE_INVIS},
-{FLAG_INV_LOCKED,V_INV_LOCKED}
+{FLAG_INV_LOCKED,V_INV_LOCKED},{FLAG_IS_WOODED,V_IS_WOODED},
+{FLAG_IS_HILLY,V_IS_HILLY},{FLAG_READY_SKILL,V_HAS_READY_SKILL},
+{FLAG_READY_WEAPON,V_HAS_READY_WEAPON}
 };
 
 void save_double(char *buf,char *name,double v)
