@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_los_c =
- *   "$Id: los.c,v 1.14 1994/12/30 05:39:05 master Exp $";
+ *   "$Id: los.c,v 1.15 1995/07/24 22:03:47 master Exp $";
  */
 
 /*
@@ -226,13 +226,6 @@ void check_wall(object *op,int x,int y) {
   }
 }
 
-#if 0
-void set_los(object *op) {
-  (void)memset((void *)op->contr->blocked_los,1,
-               (WINRIGHT-WINLEFT+1)*(WINLOWER-WINUPPER+1));
-}
-#endif
-
 /*
  * Clears/initialises the los-array associated to the player
  * controlling the object.
