@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_object_c =
- *   "$Id: object.c,v 1.36 1995/04/15 03:14:56 master Exp master $";
+ *   "$Id: object.c,v 1.38 1995/09/11 02:44:37 master Exp master $";
  */
 
 /*
@@ -36,6 +36,7 @@
 #include <global.h>
 #include <object.h>
 #include <funcpoint.h>
+#include <skills.h> 
 
 extern int penalty;
 
@@ -808,6 +809,7 @@ void sub_weight (object *op, signed long weight) {
       weight=(signed long)(weight*(100-op->stats.Str)/100);
     }
     op->carrying-=weight;
+    if (op->carrying<0) op->carrying=0;
     op = op->env;
   }
 }
@@ -1012,20 +1014,32 @@ void insert_ob_in_map_simple(object *op, mapstruct *m)
 
     tmp = top;
 
-    /*
-     * Rule 0: SEE_ANYWHERE() objects stay on top of the top.
+    /* Re-did this with nested if statements.  In this way, each check does
+     * not need to check for the previous state - to me, it makes the code
+     * cleaner, and perhaps faster.
      */
-    while(tmp != NULL && QUERY_FLAG(tmp,FLAG_SEE_ANYWHERE) &&
-       !QUERY_FLAG(op,FLAG_SEE_ANYWHERE))
+    if (!QUERY_FLAG(op, FLAG_SEE_ANYWHERE)) {
+      /* See anywhere objects stay on top. */
+      while(tmp != NULL && QUERY_FLAG(tmp,FLAG_SEE_ANYWHERE))
           top = tmp, tmp = tmp->below;
 
-    /*
-     * Rule 1: Alive objects stay on top.
-     */
-    while(tmp != NULL && QUERY_FLAG(tmp,FLAG_ALIVE) &&
-	!QUERY_FLAG(op,FLAG_ALIVE) && !QUERY_FLAG(op,FLAG_FLYING) &&
-          !QUERY_FLAG(op,FLAG_SEE_ANYWHERE))
-      top = tmp, tmp = tmp->below;
+      if (!QUERY_FLAG(op, FLAG_ALIVE) && !QUERY_FLAG(op,FLAG_FLYING)) {
+	/* Alive objects also stay on to. */
+	while(tmp != NULL && QUERY_FLAG(tmp,FLAG_ALIVE))
+	  top = tmp, tmp = tmp->below;
+
+	/* Have object 'fall below' other objects that block view, except in
+	 * cases where the object has a high visibility (high meaning >0)
+	 */
+	if (blocks_view(op->map, op->x, op->y) && (op->face &&
+		!op->face->visibility)) {
+	  while (tmp != NULL && QUERY_FLAG(tmp, FLAG_BLOCKSVIEW) &&
+	    !QUERY_FLAG(op, FLAG_BLOCKSVIEW))
+	      top = tmp, tmp = tmp->below;
+	}
+      }
+    }
+
 
     /*
      * Link the new object in the two-way list:
@@ -1121,7 +1135,8 @@ void insert_ob_in_map(object *op,mapstruct *m) {
   op->map=m;
   CLEAR_FLAG(op,FLAG_APPLIED); /* hack for fixing F_APPLIED in items of dead people */
   CLEAR_FLAG(op, FLAG_INV_LOCKED);
-  if((top=get_map_ob(op->map,op->x,op->y))!=NULL) { /* If anything below then */
+  /* If there are other objects, then */
+  if((top=get_map_ob(op->map,op->x,op->y))!=NULL) {
     /*
      * There is at least one object present, so we must figure out the order.
      * First figure out what is on top;
@@ -1132,20 +1147,31 @@ void insert_ob_in_map(object *op,mapstruct *m) {
 
     tmp = top;
 
-    /*
-     * Rule 0: SEE_ANYWHERE() objects stay on top of the top.
+    /* Re-did this with nested if statements.  In this way, each check does
+     * not need to check for the previous state - to me, it makes the code
+     * cleaner, and perhaps faster.
      */
-    while(tmp != NULL && QUERY_FLAG(tmp,FLAG_SEE_ANYWHERE) &&
-       !QUERY_FLAG(op,FLAG_SEE_ANYWHERE))
+    if (!QUERY_FLAG(op, FLAG_SEE_ANYWHERE)) {
+      /* See anywhere objects stay on top. */
+      while(tmp != NULL && QUERY_FLAG(tmp,FLAG_SEE_ANYWHERE))
           top = tmp, tmp = tmp->below;
 
-    /*
-     * Rule 1: Alive objects stay on top.
-     */
-    while(tmp != NULL && QUERY_FLAG(tmp,FLAG_ALIVE) &&
-	!QUERY_FLAG(op,FLAG_ALIVE) && !QUERY_FLAG(op,FLAG_FLYING) &&
-          !QUERY_FLAG(op,FLAG_SEE_ANYWHERE))
-      top = tmp, tmp = tmp->below;
+      if (!QUERY_FLAG(op, FLAG_ALIVE) && !QUERY_FLAG(op,FLAG_FLYING)) {
+	/* Alive objects also stay on to. */
+	while(tmp != NULL && QUERY_FLAG(tmp,FLAG_ALIVE))
+	  top = tmp, tmp = tmp->below;
+
+	/* Have object 'fall below' other objects that block view, except in
+	 * cases where the object has a high visibility (high meaning >0)
+	 */
+	if (blocks_view(op->map, op->x, op->y) && (op->face &&
+		!op->face->visibility)) {
+	  while (tmp != NULL && QUERY_FLAG(tmp, FLAG_BLOCKSVIEW) &&
+	    !QUERY_FLAG(op, FLAG_BLOCKSVIEW))
+	      top = tmp, tmp = tmp->below;
+	}
+      }
+    }
 
     /*
      * Link the new object in the two-way list:
@@ -1442,6 +1468,9 @@ object *insert_ob_in_ob(object *op,object *where) {
  * Any speed-modification due to SLOW_MOVE() of other present objects
  * will affect the speed_left of the object.
  */
+ /* 4-21-95 added code to check if appropriate skill was readied - this will
+  * permit faster movement by the player through this terrain. -b.t.
+  */
 
 void check_walk_on(object *op) {
   object *tmp;
@@ -1450,8 +1479,18 @@ void check_walk_on(object *op) {
   for(tmp=op->below;tmp!=NULL;tmp=tmp->below) {
     if (tmp==tmp->below)	/* why? mta */
        break;
-    if(QUERY_FLAG(tmp,FLAG_SLOW_MOVE)&&!QUERY_FLAG(op,FLAG_FLYING))
-      op->speed_left -= SLOW_PENALTY(tmp)*FABS(op->speed);
+    if(QUERY_FLAG(tmp,FLAG_SLOW_MOVE)&&!QUERY_FLAG(op,FLAG_FLYING)) { 
+	if(op->type==PLAYER && op->chosen_skill) { 
+             if((QUERY_FLAG(tmp,FLAG_IS_HILLY) && op->contr->shoottype == range_skill 
+		&& op->chosen_skill->stats.sp==SK_CLIMBING) 
+	        || (QUERY_FLAG(tmp,FLAG_IS_WOODED) && op->contr->shoottype == range_skill
+		&& op->chosen_skill->stats.sp==SK_WOODSMAN))
+      		    op->speed_left -= (SLOW_PENALTY(tmp)*FABS(op->speed))/4;
+             else 
+		op->speed_left -= SLOW_PENALTY(tmp)*FABS(op->speed);
+	} else 
+		op->speed_left -= SLOW_PENALTY(tmp)*FABS(op->speed);
+    }
     if(QUERY_FLAG(op,FLAG_FLYING)?QUERY_FLAG(tmp,FLAG_FLY_ON):
       QUERY_FLAG(tmp,FLAG_WALK_ON)) {
 #if 0
