@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_player_c =
- *   "$Id: player.c,v 1.22 1994/12/30 05:56:33 master Exp $";
+ *   "$Id: player.c,v 1.24 1995/09/11 02:47:03 master Exp master $";
  */
 
 /*
@@ -37,7 +37,7 @@ player *get_player_ob() {
   int i;
   player *new,*tmp;
 
-  new = (player *) calloc(1,sizeof(player));
+  new = (player *) CALLOC(1,sizeof(player));
   if(new==NULL)
     fatal(OUT_OF_MEMORY);
   if(!editor) {
@@ -54,6 +54,8 @@ player *get_player_ob() {
   new->sync = synchronize;
   new->cur_sync = 1;
   new->known_spell = 0;
+  new->removed=0;
+  new->party_number=0;
   new->last_known_spell = 0;
   new->infoline=0;
   new->infopos=0;
@@ -61,16 +63,19 @@ player *get_player_ob() {
   new->keyboard_flush=0;
   new->infolines=INFOLINES;
   new->infochars=INFOCHARS;
+  new->gc_root=NULL;
+  new->gc_xpm_floor=NULL;
+  new->gc_xpm_object=NULL;
   new->info=(char **) malloc(sizeof(char *) * new->infolines);
   for(i=0;i<new->infolines;i++) {
     new->info[i]=(char *) malloc(sizeof(char) * (new->infochars + 1));
     strcpy(new->info[i]," ");
   }
-  for(i=0;i<LOOK_SIZE;i++) {
+  for(i=0;i<MAX_LOOK_SIZE;i++) {
     new->look_name[i]=NULL;
     new->look_face[i]=blank_face->number;
   }
-  for(i=0;i<INV_SIZE;i++) {
+  for(i=0;i<MAX_INV_SIZE;i++) {
     new->inv_name[i]=NULL;
     new->inv_face[i]=blank_face->number;
   }
@@ -82,10 +87,14 @@ player *get_player_ob() {
   for(i=0;i<COMMAND_HASH_SIZE;i++)
     new->keys[i] =NULL;
   new->key_state=0;
+  new->key_down=0;
+  new->state=0;
 
   new->use_pixmaps = 0;
   new->pixmaps = NULL;
   new->masks = NULL;
+  new->use_pixmaps=0;
+  new->color_pixmaps=0;
   new->ob = get_object();
   new->ob->name = add_string("logon");
   new->ob->type = PLAYER;
@@ -95,9 +104,27 @@ player *get_player_ob() {
   new->username = NULL;
   new->shoottype = range_none;
   new->last_shoot = range_size;
+  new->no_echo =0;
+  new->split_window =0;
+  new->braced =0;
+  new->search_str[0]=0;
+#if 0
+  memset(new->mapdelx, 0, 32);
+  memset(new->mapdely, 0, 32);
+#endif
+
+#ifdef SAVE_WINDOW_POSITIONS
+  new->valid_save_positions =0;
+  memset(new->win_pos, 0, 6*sizeof(save_win_pos));
+#endif
 #ifdef USE_SWAP_STATS
   new->Swap_First = -1;
 #endif
+#ifdef SOUND_EFFECTS
+  new->play_count=0;
+  new->rplay_fd=0;
+#endif
+
   for (i=0; i<NUM_OUTPUT_BUFS; i++) {
 	new->outputs[i].buf=NULL;
 	new->outputs[i].first_update=0;
