@@ -1,7 +1,7 @@
 
 /*
  * static char *rcsid_porting_c =
- *   "$Id: porting.c,v 1.5 1995/04/15 03:16:12 master Exp master $";
+ *   "$Id: porting.c,v 1.6 1995/07/24 22:06:38 master Exp $";
  */
 
 /*
@@ -204,7 +204,7 @@ struct xdirect *xreaddir(dir_ptr, mask)
 }
 
 /* This seems to be lacking on some system */
-#if defined(SVR4) && !defined(__sgi__)
+#if defined(SVR4) && !defined(__sgi__) && !defined(sun)
 int strncasecmp(char *s1, char *s2, int n)
 {
   register int c1, c2;
@@ -224,7 +224,7 @@ int strncasecmp(char *s1, char *s2, int n)
 }
 
 
-
+#if !defined(Xpm_Pix)
 int strcasecmp(char *s1, char*s2)
 {
   register int c1, c2;
@@ -242,3 +242,4 @@ int strcasecmp(char *s1, char*s2)
   return (int) (*s1 - *s2);
 }
 #endif
+#endif
