@@ -1,7 +1,7 @@
 
 /*
  * static char *rcs_treasure_c =
- *   "$Id: treasure.c,v 1.37 1995/04/15 03:17:03 master Exp master $";
+ *   "$Id: treasure.c,v 1.38 1995/09/11 02:47:35 master Exp master $";
  */
 
 /*
@@ -136,7 +136,7 @@ static treasure *load_treasure(FILE *fp) {
       t->next=load_treasure(fp);
       return t;
     } else
-      LOG(llevError,"Unknown treasure-command: %s\n",cp);
+      LOG(llevError,"Unknown treasure-command: '%s', last entry %s\n",cp,t->name);
   }
   LOG(llevError,"treasure lacks 'end'.\n");
   return t;
