@@ -61,6 +61,13 @@ ArchFlagsRec archFlags[] = {
     { 0, NULL, 		0 },
 };
 
+/*
+ * plaah: where to put these ???
+ * 0.91.9 - moved to start of file - needed for ReadPixmaps function.
+ */
+XColor exactcolor, discolor[13];
+Colormap colormap;
+
 
 /**********************************************************************
  * private
@@ -743,6 +750,7 @@ App AppCreate(XtAppContext appCon,
 	XtAppError(appCon,buf);
 	exit(EXIT_FAILURE);
     }
+
     BitmapsCreate(self->display); 
     self->shell = XtVaAppCreateShell
 	(NULL,AppClass,
@@ -750,7 +758,7 @@ App AppCreate(XtAppContext appCon,
 	 self->display,
 	 XtNtitle,AppClass,
 	 XtNiconName,AppClass,
-	 XtNiconPixmap,bitmaps.edit, 
+	 XtNiconPixmap,bitmaps.edit,
 	 NULL);
     self->attr = NULL;
     self->edit = NULL;
@@ -771,6 +779,9 @@ App AppCreate(XtAppContext appCon,
 	 resources, resourcesNum, 
 	 NULL, 0);
 
+    /*** images & colors ***/
+    InitializeColors(XtDisplay(self->shell));
+
     use_pixmaps = self->res.usePixmaps; /* kludge */
 #ifdef Xpm_Pix
     color_pix = self->res.useColorPixmaps; /* kludge, do not use */
@@ -781,11 +792,13 @@ App AppCreate(XtAppContext appCon,
 
     CnvInitialize(self->shell);
 
-    /*** images & colors ***/
-    if(self->res.useColorPixmaps) {
-	ReadPixmaps(self->display, &pixmaps, &masks);
+    if(color_pix) {
+	if (ReadPixmaps(self->display, &pixmaps, &masks, &colormap)) {
+	    /* We really should do something better than this */
+	    fprintf(stderr,"Not enough space in colormap - exiting.\n");
+	    exit(1);
+	}
     } else {
-	InitializeColors(XtDisplay(self->shell));
 	if (use_pixmaps)
 	    pixmaps = ReadBitmaps(self->display);
 	else if (!check_font_path(XtDisplay (self->shell))) {
@@ -797,7 +810,8 @@ App AppCreate(XtAppContext appCon,
 	    }
 	}
     }
-    
+    XtVaSetValues(self->shell, XtNcolormap, colormap, NULL);
+
     /*** creating ***/
     sprintf(path,"%s/%s",LibDir,MapDir);
     self->path = CnvPathCreate("fileSelect",path, "");
@@ -805,7 +819,6 @@ App AppCreate(XtAppContext appCon,
     Layout(self);
     XtRealizeWidget (self->shell);
     XtRealizeWidget(self->clip->shell);
-
     AppUpdate(self);
     return self;
 }
@@ -961,12 +974,6 @@ void AppItemSet (App self, Edit edit,object *obj,int wallSet)
 }
 
 
-/*
- * plaah: where to put these ???
- */
-XColor exactcolor, discolor[13];
-Colormap colormap;
-
 char PixelFromAlias(char *name) {
   int i;
   for(i=0;i<13;i++)
@@ -979,6 +986,7 @@ char PixelFromAlias(char *name) {
 void  InitializeColors (Display *dpy)
 {
     int i;
+    int private=0;
 
     colormap = DefaultColormap (dpy, DefaultScreen (dpy));
     for (i = 0; i < 13; i++) {
@@ -987,7 +995,15 @@ void  InitializeColors (Display *dpy)
 	    die ("Can't find color.");
 	}
 	if (!XAllocColor (dpy, colormap, &discolor[i])) {
-	    die ("Can't allocate colors.");
+	    if (!private) {
+		LOG(llevDebug,"Switching to a private colormap.\n");
+		colormap=XCopyColormapAndFree(dpy, colormap);
+		private=1;
+		if (!XAllocColor (dpy, colormap, &discolor[i]))
+		    die ("Can't allocate colors.");
+	    }
+	    else 
+		die ("Can't allocate colors.");
 	}
     }
 }
