@@ -50,7 +50,7 @@
  * start with skills.
  */
 
-/* #define ALLOW_SKILLS */
+#define ALLOW_SKILLS
 
 /* Following uses a new weapon improvement system.  This makes it more
  * difficult to get a super weapon, and makes it more likely that
