@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_define_h =
- *   "$Id: define.h,v 1.42 1995/04/15 04:32:13 master Exp master $";
+ *   "$Id: define.h,v 1.43 1995/09/11 03:01:15 master Exp master $";
  */
 
 /*
@@ -441,9 +441,14 @@
 #define FLAG_USE_HORN		84 /* (Monster) can apply and use horns */
 #define FLAG_MAKE_INVIS	        85 /* (Item) gives invisibility when applied */
 #define FLAG_INV_LOCKED		86 /* Item will not be dropped from inventory */
+#define FLAG_IS_WOODED		87 /* Item is wooded terrain */
+#define FLAG_IS_HILLY		88 /* Item is hilly/mountain terrain */
+#define FLAG_READY_SKILL	89 /* (Monster or Player) has a skill readied */
+#define FLAG_READY_WEAPON	90 /* (Monster or Player) has a weapon readied */
 
-#define NUM_FLAGS		86 /* Should always be equal to the last
+#define NUM_FLAGS		90 /* Should always be equal to the last
 				    * defined flag */
+
 /* Values can go up to 95 before the size of the flags array in the
  * object structure needs to be enlarged.
  */
