@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_spells_h =
- *   "$Id: spells.h,v 1.21 1995/04/15 04:34:27 master Exp master $";
+ *   "$Id: spells.h,v 1.22 1995/09/11 03:04:23 master Exp master $";
  */
 
 /*
@@ -133,7 +133,7 @@ enum spellnrs {
 
 
 #define IS_SUMMON_SPELL(spell) (((spell) > SP_BOMB && (spell) < SP_D_DOOR) \
-	|| ((spell) = SP_MYSTIC_FIST))
+	|| ((spell) == SP_MYSTIC_FIST))
 
 #define PATH_SP_MULT(op,spell) (((op->path_attuned & s->path) ? 0.8 : 1) * \
 				((op->path_repelled & s->path) ? 1.25 : 1))
