@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_structs_h =
- *   "$Id: structs.h,v 1.47 1995/04/15 04:34:52 master Exp master $";
+ *   "$Id: structs.h,v 1.48 1995/09/11 03:05:07 master Exp master $";
  */
 
 /*
@@ -80,12 +80,6 @@ typedef struct liv { /* Mostly used by "alive" objects */
   signed char luck;	/* Affects thaco and ac from time to time */
 } living;
 
-#if 0
-typedef struct face_struct {
-    unsigned short number;
-    unsigned char fg, bg;
-} Face;
-#endif
 
 /* New face structure - this enforces the notion that data is face by
  * face only - you can not change the color of an item - you need to instead
@@ -117,8 +111,12 @@ typedef struct obj {
   struct obj *above;   /* Pointer to the object stacked above this one */
 	         /* Note: stacked in the *same* environment*/
   struct obj *inv;     /* Pointer to the first object in the inventory */
-  struct obj *container; /* Current container being used */
-  struct obj *env;     /* Pointer to the object which is the environment */
+  struct obj *container; /* Current container being used.  I think this
+			  * is only used by the player right now.
+			  */
+  struct obj *env;     /* Pointer to the object which is the environment.
+			* This is typically the container that the object is in.
+			*/
   struct obj *more;    /* Pointer to the rest of a large body of objects */
   struct obj *head;    /* Points to the main object of a large body */
   struct mapdef *map;  /* Pointer to the map in which this object is present */
@@ -141,7 +139,7 @@ typedef struct obj {
   New_Face *face;			/* Face with colors */
   signed char direction;        /* Means the object is moving that way. */
   sint8 facing;			/* Object is oriented/facing that way. */
-  uint8 type;           /* PLAYER, BULLET, etc */
+  uint8 type; 		        /* PLAYER, BULLET, etc.  See define.h */
   unsigned int immune;          /* Attacks which the object is immune against */
   unsigned int protected;	/* Attacks which does half damage */
   unsigned int attacktype;      /* Same bitmask as immune/protected */
@@ -158,11 +156,12 @@ typedef struct obj {
   signed short last_heal;       /* Last healed. Depends on constitution */
   signed short last_sp;         /* As last_heal, but for spell points */
   signed short last_eat;	/* How long since we last ate */
-  uint32 hide;			/* The player is hidden, not invisible */
   signed short invisible;	/* How much longer the object will be invis */
   signed char armour;		/* How many % is subtracted from phys. damage */
   unsigned char pick_up;        /* See crossfire.doc */
-  struct obj *owner;   /* Pointer to the object which controls this one */
+  struct obj *owner;	/* Pointer to the object which controls this one */
+			/* Owner should not be referred to directly - */
+			/* get_owner should be used instead. */
   struct obj *enemy;   /* Monster/player to follow even if not closest */
   struct archt *arch;           /* Pointer to archetype */
   struct archt *other_arch;	/* Pointer used for various things */
@@ -181,7 +180,14 @@ typedef struct obj {
   unsigned short npc_status;	/* What the NPC is doing right now */
   unsigned short npc_program;	/* Helps find out what the NPC will do next */
 #endif
+ 
+/* Not commented out by ALLOW_SKILLS - to many pieces of code want this
+ * information
+ */
+  struct obj *chosen_skill;	/* the skill chosen to use */
+  uint32 hide;			/* The object is hidden, not invisible */
 
+ 
 /* changes made by kholland@sunlab.cit.cornell.edu */
 /* allows different movement patterns for attackers */
   signed long move_status;      /* What stage in attack mode */
@@ -328,7 +334,6 @@ typedef struct pl {
   unsigned last_known_spell:1;/* What was last updated with draw_stats() */
   rangetype shoottype;	      /* Which range-attack is being used by player */
   rangetype last_shoot;	      /* What was last updated with draw_stats() */
-  sint16 chosen_skill;  	/* Skill readied for use by the player */
   sint16 chosen_spell;		/* Type of readied spell */
   sint16 last_spell;		/* What spell draw_stats() last displayed */
   sint16 chosen_item_spell;	/* Type of spell that the item fires */
@@ -379,7 +384,7 @@ typedef struct pl {
   signed short nrofdrawn_inv;	  /* How many items drawn. Delete extras */
   signed short nrofdrawn_look;    /* ditto for the look-window */
   signed short inv_chars;         /* How wide the text-field is */
-  signed short look_chars;        /* How wide the text-field is */
+  sint16 look_chars;		  /* How wide the text-field is */
   char format_inv[16];            /* printf-format for text in inv. window */
   char format_look[16];           /* printf-format for text in look window */
   unsigned short barlength_inv;   /* height of scrollbar in pixels */
