@@ -1,7 +1,7 @@
 
 /*
  * static char *rcsid_apply_c =
- *   "$Id: apply.c,v 1.45 1995/04/15 04:45:57 master Exp master $";
+ *   "$Id: apply.c,v 1.47 1995/09/11 03:13:48 master Exp master $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -1485,6 +1485,24 @@ int apply(object *op, object *tmp) {
       }
     }
     return 1;
+
+  case SKILL:	/* allows objects which impart skills to be applied -b.t */
+    if(apply_special(op,tmp))
+      return 0;
+    if(QUERY_FLAG(tmp, FLAG_APPLIED)) {
+        SET_FLAG(op, FLAG_READY_SKILL);
+        op->chosen_skill=tmp;
+        if(op->type==PLAYER) {
+          new_draw_info_format(NDI_UNIQUE, 0, op,
+             "You can now use the skill: %s.", skills[tmp->stats.sp].name);
+          op->contr->shoottype=range_skill;
+          fix_player(op);
+	  draw_stats(op);
+        }  
+    } else  
+        CLEAR_FLAG(op, FLAG_READY_SKILL);
+    return 1;
+
   case WEAPON:
   case ARMOUR:
   case BOOTS:
@@ -1515,14 +1533,18 @@ int apply(object *op, object *tmp) {
 	  new_draw_info(NDI_UNIQUE, 0,op,"You can't possibly drink all that now.");
 	return 1;
       }
-      if(tmp->type==FOOD)
-        new_draw_info(NDI_UNIQUE, 0,op,"The food tasted good.");
-      else
-        new_draw_info(NDI_UNIQUE, 0,op,"Ahhh...that booze tasted good.");
-      op->stats.food+=tmp->stats.food;
-      op->stats.hp+=tmp->stats.food/50;
-      if(op->stats.hp>op->stats.maxhp)
-        op->stats.hp=op->stats.maxhp;
+      if(!QUERY_FLAG(tmp, FLAG_CURSED)) {
+        if(tmp->type==FOOD)
+          new_draw_info(NDI_UNIQUE, 0,op,"The food tasted good.");
+        else 
+          new_draw_info(NDI_UNIQUE, 0,op,"Ahhh...that booze tasted good.");
+        op->stats.food+=tmp->stats.food;
+        op->stats.hp+=tmp->stats.food/50;
+        if(op->stats.hp>op->stats.maxhp)
+          op->stats.hp=op->stats.maxhp;
+      }
+      /* special food hack -b.t. */
+      if(tmp->title || QUERY_FLAG(tmp,FLAG_CURSED)) eat_special_food(op,tmp);
       draw_stats(op);
     }
     decrease_ob(tmp);
@@ -1745,7 +1767,27 @@ int apply_special(object *who,object *op) { /* wear/wield */
         return 1;
       }
       sprintf(buf,"You unwield %s.",query_name(op));
+      CLEAR_FLAG(who, FLAG_READY_WEAPON);
       break;
+
+    case SKILL:		/* allows objects to impart skills */
+      if(!change_abil(who,op)) {
+        new_draw_info_format(NDI_UNIQUE, 0, who,
+            "You can't stop using the %s.",query_name(op));
+        SET_FLAG(op, FLAG_APPLIED);
+        return 1;
+      }  
+      if(who->type==PLAYER) {
+        new_draw_info_format(NDI_UNIQUE, 0, who,
+            "You can no longer use the skill: %s.",skills[op->stats.sp].name);
+        who->contr->shoottype=range_none;
+        who->contr->last_value = -1;
+      }
+      CLEAR_FLAG(who, FLAG_READY_SKILL);
+      who->chosen_skill=NULL;
+      sprintf(buf,"You stop using the %s.",query_name(op));
+      break; 
+
     case ARMOUR:
     case HELMET:
     case SHIELD:
@@ -1855,6 +1897,7 @@ int apply_special(object *who,object *op) { /* wear/wield */
       return 1;
     }
     sprintf(buf,"You wield %s.",query_name(op));
+    SET_FLAG(who, FLAG_READY_WEAPON);
     break;
   case ARMOUR:
   case HELMET:
@@ -1885,6 +1928,20 @@ int apply_special(object *who,object *op) { /* wear/wield */
     }
     sprintf(buf,"You wear %s.",query_name(op));
     break;
+  case SKILL:
+    SET_FLAG(op, FLAG_APPLIED);
+    if(!change_abil(who,op)) {
+      CLEAR_FLAG(op, FLAG_APPLIED);
+      sprintf(buf,"You receive a jolt when you try to use %s.",
+              query_name(op));
+      new_draw_info(NDI_UNIQUE, 0,who,buf);
+      if(tmp!=NULL)
+        (void) insert_ob_in_ob(tmp,who);
+      return 1;
+    }
+    sprintf(buf,"You apply %s.",query_name(op));
+    SET_FLAG(who, FLAG_READY_SKILL);
+    break;
   case BOW:
   case WAND:
     sprintf(buf,"You ready %s.",query_name(op));
@@ -1997,3 +2054,56 @@ void fix_auto_apply(mapstruct *m) {
             tmp->type == TRIGGER_PEDESTAL || tmp->type == TRIGGER_ALTAR)
 	  check_trigger(tmp);
 }
+
+/* eat_special_food() - some food may (temporarily) alter
+ * player status. We do it w/ this routine and cast_change_attr().
+ * Note the dircection is set to "99"  so that cast_change_attr()
+ * will only modify the user's status. We shouldnt be able to 
+ * effect others by eating food!
+ * -b.t.
+ */
+
+void eat_special_food(object *who, object *food) {
+  /* matrix for attacks we can gain protection/immunity too from eating 
+   * be sure to perserve the ordering between at_type[] and sp_type[]! */
+  int at_type[] = { AT_PHYSICAL, AT_MAGIC, AT_FIRE, AT_ELECTRICITY, AT_COLD, 
+              AT_DRAIN, AT_POISON, AT_SLOW, AT_PARALYZE, AT_CANCELLATION,
+	      AT_DEPLETE, AT_FEAR }; 
+  int sp_type[] = { SP_ARMOUR, SP_PROT_MAGIC, SP_PROT_FIRE, SP_PROT_ELEC, SP_PROT_COLD, 
+	      SP_PROT_DRAIN, SP_PROT_POISON, SP_PROT_SLOW, SP_PROT_PARALYZE, SP_PROT_CANCEL, 
+	      SP_PROT_DEPLETE, SP_HEROISM }; 
+  /* matrix for stats we can increase by eating */
+  int i, stat[] = { STR, DEX, CON, CHA };
+  int mod_stat[] = {SP_STRENGTH, SP_DEXTERITY, SP_CONSTITUTION, SP_CHARISMA };
+  
+  /* check if food modifies stats of the eater */
+  for(i=0; i<(sizeof(stat)/sizeof(int)); i++)
+     if(get_attr_value(&food->stats, stat[i]))
+          cast_change_attr(who,99,mod_stat[i]);
+
+  /* check if we can protect the eater */
+  if(food->protected)
+     for(i=0; i<(sizeof(at_type)/sizeof(int)); i++)
+  	if(food->protected&at_type[i]) cast_change_attr(who,99,sp_type[i]);
+
+  /* check for hp, sp change */
+  if(food->stats.hp!=0) 
+     if(QUERY_FLAG(food, FLAG_CURSED)) { 
+         new_draw_info(NDI_UNIQUE, 0,who,"Eck!...that was poisonous!");
+ 	 who->stats.hp -= food->stats.hp;
+     } else { 
+         new_draw_info(NDI_UNIQUE, 0,who,"You begin to feel better.");
+  	 who->stats.hp += food->stats.hp;
+     }
+  if(food->stats.sp!=0) 
+     if(QUERY_FLAG(food, FLAG_CURSED)) { 
+         new_draw_info(NDI_UNIQUE, 0,who,"You are drained of mana!");
+	 who->stats.sp -= food->stats.sp; 
+         if(who->stats.sp<0) who->stats.sp=0;
+     } else { 
+         new_draw_info(NDI_UNIQUE, 0,who,"You feel a rush of magical energy!");
+	 who->stats.sp += food->stats.sp; 
+	/* place limit on max sp from food? */
+     }
+
+}
