@@ -81,6 +81,9 @@ int command_stay (object *op, char *params)
             is:  it might be hidden underneath something.
   It searches both around the player--9 squares counting the one he's on
   and the inventories of all the objects around him for traps.  (Including his own!!  Hmmm.)
+
+  4-21-95 I modified trap_see to allow greater trapdetection with the find trap
+  skill. This needs to be carried over into this routine here. -b.t.
 */
 
 int command_search (object *op, char *params)
@@ -97,8 +100,8 @@ int command_search (object *op, char *params)
 	    /*  And now we'd better do an inventory traversal of each
 	        of these objects' inventory */
 	    for(tmp2=tmp->inv;tmp2!=NULL;tmp2=tmp2->below) 
-		if(tmp2->type==RUNE) { if(trap_see(op,tmp2)) trap_show(tmp2,tmp); }
-	    if(tmp->type==RUNE) { if(trap_see(op,tmp)) trap_show(tmp,tmp);}
+		if(tmp2->type==RUNE) { if(trap_see(op,tmp2,0)) trap_show(tmp2,tmp); }
+	    if(tmp->type==RUNE) { if(trap_see(op,tmp,0)) trap_show(tmp,tmp);}
 	    }
    }
   return 0;
