@@ -219,6 +219,7 @@ int command_apply (object *op, char *params)
 }
 
 /* Pick up commands follow */
+
 void pick_up_object (object *pl, object *op, object *tmp, int nrof)
 {
     char buf[MAX_BUF];
@@ -274,6 +275,7 @@ void pick_up_object (object *pl, object *op, object *tmp, int nrof)
     new_draw_info(NDI_UNIQUE, 0,op,buf);
 
     tmp = insert_ob_in_ob(tmp, op);
+    if(pl->type!=PLAYER) return;
     if (pl->contr->eric_server > 0) {
 	esrv_send_item (pl, tmp);
     } else {
@@ -289,6 +291,7 @@ void pick_up_object (object *pl, object *op, object *tmp, int nrof)
 
 
 void pick_up(object *op,object *alt) 
+/* modified slightly to allow monsters use this -b.t. 5-31-95 */
 {
     object *tmp=NULL, *split=NULL;
 
@@ -306,7 +309,7 @@ void pick_up(object *op,object *alt)
 	if (alt != tmp->env && !sack_can_hold (op, alt, tmp))
 	    return;
     } else {
-	if (op->contr->count && op->contr->count <tmp->nrof)
+	if (op->type==PLAYER && op->contr->count && op->contr->count <tmp->nrof)
 	    split = get_split_ob(tmp, op->contr->count);
 	else
 	    split = tmp;
@@ -342,8 +345,12 @@ void pick_up(object *op,object *alt)
 #ifdef PICKUP_DEBUG
     printf ("Pick_up(): %s picks %s (%d) and inserts it %s.\n",op->name, tmp->name,  op->contr->count, alt->name);
 #endif
-    pick_up_object(op, alt, tmp, op->contr->count);
-    op->contr->count=0;
+    if(op->type==PLAYER) { 
+       pick_up_object(op, alt, tmp, op->contr->count);
+       op->contr->count=0;
+    } else 
+       pick_up_object(op, alt, tmp, tmp->nrof);
+    
 }
 #if 0
 
@@ -506,6 +513,11 @@ void put_object_in_sack (object *op, object *sack, object *tmp, long nrof)
 	"%s is not a container.", query_name(sack));
       return;
     }
+    if (QUERY_FLAG(tmp,FLAG_STARTEQUIP)) {
+      new_draw_info_format(NDI_UNIQUE, 0,op,
+	"You cannot put %s in the container.", query_name(tmp));
+      return;
+    }
     if (tmp->type == CONTAINER && tmp->inv) {
 
       /* Eneq(@csd.uu.se): If the object to be dropped is a container 
@@ -745,7 +757,8 @@ int command_dropall (object *op, char *params) {
       if(! QUERY_FLAG(curinv,FLAG_INV_LOCKED) && curinv->type != MONEY &&
 	 curinv->type != FOOD && curinv->type != KEY && 
 	 curinv->type != SPECIAL_KEY && curinv->type != GEM &&
-	 !curinv->invisible)
+	 !curinv->invisible &&
+	 (curinv->type!=CONTAINER || op->container!=curinv))
 	{
 	 drop(op,curinv);
        }
