@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_input_c =
- *   "$Id: input.c,v 1.49 1995/04/15 04:54:56 master Exp master $";
+ *   "$Id: input.c,v 1.51 1995/09/11 03:14:50 master Exp master $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -210,20 +210,32 @@ void rotate_left(object *op) {
 }
 
 void change_skill(object *pl, char *name) {
+
   char buf[MAX_BUF];
   int i=0;
   object *tmp;
 
-  for(tmp=pl->inv; tmp; tmp=tmp->below) {	/* does player possess the skill? */ 
-     if(tmp->type == SKILL)		/* player does have skills */ 
+  if(pl->chosen_skill!=NULL
+     && QUERY_FLAG(pl->chosen_skill,FLAG_APPLIED)) { 
+      CLEAR_FLAG(pl->chosen_skill,FLAG_APPLIED); 
+              CLEAR_FLAG(pl,FLAG_READY_SKILL);
+  }
+
+   for(tmp=pl->inv; tmp; tmp=tmp->below) {	/* does player possess the skill? */ 
+     if(tmp->type == SKILL) {		/* player does have skills */ 
 	i++;
-     if(!strcmp(name, skills[tmp->stats.sp].name)) { /* player has named skill? */ 
-	    pl->contr->chosen_skill = tmp->stats.sp;
+        if(!strcmp(name, skills[tmp->stats.sp].name)) { /* player has named skill? */ 
             sprintf(buf,"Readying skill: %s. ",skills[tmp->stats.sp].name);
             new_draw_info(NDI_UNIQUE, 0,pl,buf);
 	    pl->contr->shoottype = range_skill;
+	    pl->chosen_skill=tmp;
+	    SET_FLAG(tmp, FLAG_APPLIED);
+	    if(!QUERY_FLAG(pl,FLAG_READY_SKILL)) 
+		SET_FLAG(pl,FLAG_READY_SKILL);
+	    fix_player(pl);
 	    draw_stats(pl);
 	    return;
+        }
      }
   }
   if(i<1)
@@ -231,6 +243,9 @@ void change_skill(object *pl, char *name) {
   else
     sprintf(buf,"You have no skill named %s.",name);
   new_draw_info(NDI_UNIQUE, 0,pl,buf);
+  if(QUERY_FLAG(pl,FLAG_READY_SKILL))         /* shouldnt happen -b.t. */ 
+    CLEAR_FLAG(pl, FLAG_READY_SKILL);
+
 }
 
 void apply_inventory(object *op) {
@@ -513,6 +528,7 @@ void inventory(object *op,object *inv) {
  */
 
 void show_skills(object *op) {
+
   object *tmp = op->inv;
   char buf[MAX_BUF], *in;
   int items = 0, length;
@@ -524,7 +540,7 @@ void show_skills(object *op) {
   }
   if (items==0) {
       new_draw_info(NDI_UNIQUE, 0,op,"You know no skills.");
-      op->contr->chosen_skill=-1;	/* double safety - for pl's who lose skills */ 
+      op->chosen_skill=NULL;	/* double safety - for those who lose skills */ 
       return;
   } else {
       length = INFOCHARS-19;
@@ -536,13 +552,16 @@ void show_skills(object *op) {
   for (tmp=op->inv; tmp; tmp=tmp->below) {
     if((!op) || (tmp->type != SKILL)) 
       continue;
-    if((!op || QUERY_FLAG(op, FLAG_WIZ)))
-      (void) sprintf(buf,"%s- %-*s (%5d)", in, length, query_name(tmp),
+    if(tmp->invisible||QUERY_FLAG(tmp,FLAG_APPLIED)) { 
+      if((!op || QUERY_FLAG(op, FLAG_WIZ)))
+        (void) sprintf(buf,"%s- %-*s (%5d)", in, length, skills[tmp->stats.sp].name,
                      tmp->count);
-    else
-      (void) sprintf(buf,"%s- %-*s", in, length+8, query_name(tmp)); 
-    new_draw_info(NDI_UNIQUE, 0,op,buf);
+      else
+        (void) sprintf(buf,"%s- %-*s", in, length+8, skills[tmp->stats.sp].name); 
+      new_draw_info(NDI_UNIQUE, 0,op,buf);
+    }
   }
+
 }
 
 /*
@@ -1691,14 +1710,16 @@ int legal_range(object *op,int r) {
     return 0;
   case range_scroll: /* Use scrolls */
     return 0;
+
   case range_skill:
       for (tmp = op->inv; tmp!=NULL; tmp=tmp->below) {
 	  if (tmp->type == SKILL) { 
 	      return 1;
 	  }
       }
-      op->contr->chosen_skill=-1;	/* they have lost all skills :) */ 
+      op->chosen_skill=NULL;	/* they have lost all skills :) */ 
       return 0;
+
   }
   return 0;
 }
@@ -1752,9 +1773,10 @@ void change_spell(object *op,char k) {
             spells[op->contr->chosen_item_spell].name : "unknown");
     break;
   case range_skill: 
-    sprintf (buf, "Switched to skill: %s", !op->contr->chosen_skill ?  
-		 skills[op->contr->chosen_skill].name : "none");
+    sprintf (buf, "Switched to skill: %s", op->chosen_skill ?  
+		 skills[op->chosen_skill->stats.sp].name : "none");
     break;
+
   default:
     break;
   }
