@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_login_c =
- *   "$Id: login.c,v 1.36 1995/04/15 04:56:01 master Exp master $";
+ *   "$Id: login.c,v 1.38 1995/09/11 03:16:04 master Exp master $";
  */
 
 /*
@@ -197,7 +197,7 @@ int create_savedir_if_needed(char *savedir)
 {
   struct stat *buf;
 
-  if ((buf = (struct stat *) calloc(1, sizeof(struct stat))) == NULL) {
+  if ((buf = (struct stat *) malloc(sizeof(struct stat))) == NULL) {
     perror("Unable to save playerfile... out of memory.");
     return 0;
   } else {
@@ -232,6 +232,7 @@ void destroy_object (object *op)
  * If flag is set, it's only backup, ie dont remove objects from inventory
  * If BACKUP_SAVE_AT_HOME is set, and the flag is set, then the player
  * will be saved at the emergency save location.
+ * Returns non zero if successful.
  */
 
 int save_player(object *op, int flag) {
