@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_main_c =
- *    "$Id: main.c,v 1.34 1995/04/15 04:56:36 master Exp master $";
+ *    "$Id: main.c,v 1.35 1995/07/24 22:15:00 master Exp $";
  */
 
 /*
@@ -258,6 +258,9 @@ void enter_exit(object *op, object *exit_ob) {
   op->contr->count=0;
   op->contr->count_left=0;
 
+  if(exit_ob && exit_ob->stats.dam && op->type==PLAYER)
+       hit_player(op,exit_ob->stats.dam,exit_ob,exit_ob->attacktype);
+
   /* Keep track of the map the player is on right now */
   m=op->map;
 
