@@ -1,7 +1,6 @@
-
 /*
  * static char *rcsid_monster_c =
- *    "$Id: monster.c,v 1.22 1995/04/15 04:57:47 master Exp master $";
+ *    "$Id: monster.c,v 1.23 1995/07/24 22:15:14 master Exp $";
  */
 
 /*
@@ -223,6 +222,11 @@ int move_monster(object *op) {
     if(QUERY_FLAG(op,FLAG_READY_BOW)&&!(RANDOM()%2))
       if(monster_use_bow(op,part,enemy,dir))
         return 0;
+    if(QUERY_FLAG(op,FLAG_READY_SKILL)&&!(RANDOM()%3))
+#ifdef ALLOW_SKILLS
+      if(monster_use_skill(op,part,enemy,dir))
+#endif
+	return 0;
   }
   if ((op->move_type & LO4) && !QUERY_FLAG(op, FLAG_SCARED)) {
      switch (op->move_type & LO4) {
@@ -391,6 +395,40 @@ int monster_cast_spell(object *head, object *part,object *pl,int dir) {
   return cast_spell(part,part,dir,sp_typ,ability, spellNormal,NULL);
 }
 
+/* implemented 95-04-28 to allow monster skill use - bt. */
+#ifdef ALLOW_SKILLS
+
+int monster_use_skill(object *head, object *part, object *pl,int dir) {
+object *skill, *owner;
+
+  if(!(dir=path_to_player(part,pl,0)))
+    return 0;
+  if(QUERY_FLAG(head,FLAG_FRIENDLY) && (owner = get_owner(head)) != NULL) {
+    int dir2 = find_dir_2(head->x-owner->x, head->y-owner->y);
+    if(dirdiff(dir,dir2) < 1)
+      return 0; /* Might hit owner with skill -thrown rocks for example ?*/
+  }
+  if(QUERY_FLAG(head,FLAG_CONFUSED))
+    dir = absdir(dir + RANDOM()%3 + RANDOM()%3 - 2);
+
+  for(skill=head->inv;skill!=NULL;skill=skill->below)
+    if(skill->type==SKILL
+	/* &&QUERY_FLAG(skill,FLAG_APPLIED) */
+      )
+      break;
+  if(!skill) {
+    LOG(llevError,"Error: Monster %s (%d) HAS_READY_SKILL without skill.\n",
+        head->name,head->count);
+    CLEAR_FLAG(head, FLAG_READY_SKILL);
+    return 0;
+  }
+/* use_skill */
+  head->chosen_skill=skill; 
+  return do_skill(head,dir);
+}
+
+#endif 
+
 /* For the future: Move this function together with case 3: in fire() */
 
 int monster_use_wand(object *head,object *part,object *pl,int dir) {
