@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_player_c =
- *   "$Id: player.c,v 1.50 1995/04/15 04:59:21 master Exp master $";
+ *   "$Id: player.c,v 1.51 1995/07/24 22:16:10 master Exp $";
  */
 
 /*
@@ -206,13 +206,22 @@ int add_player(char *disp, char *username, mapstruct *m, int esrv_client) {
       return 1;
     }
 
+    setuperrors();
     /* Is there any reason that the values checked for in the if statements
      * need to be re-set below them?  MSW (master@rahul.net)
      */
     if (p->color_pixmaps) {
 	p->color_pixmaps = 1;
 	p->use_pixmaps = 1;
-	ReadPixmaps(p->gdisp, &p->pixmaps, &p->masks);
+	if (ReadPixmaps(p->gdisp, &p->pixmaps, &p->masks,&p->colormap)) {
+	    if (!p->split_window)
+		XSetWindowColormap(p->gdisp, p->win_root, p->colormap);
+	    XSetWindowColormap(p->gdisp, p->win_game, p->colormap);
+	    XSetWindowColormap(p->gdisp, p->win_info, p->colormap);
+	    XSetWindowColormap(p->gdisp, p->win_message, p->colormap);
+	    XSetWindowColormap(p->gdisp, p->win_inv, p->colormap);
+	    XSetWindowColormap(p->gdisp, p->win_look, p->colormap);
+	}
     }
     else if(p->use_pixmaps) {
       p->use_pixmaps = 1;
@@ -221,7 +230,6 @@ int add_player(char *disp, char *username, mapstruct *m, int esrv_client) {
 
     load_default_keys(p);
 
-    setuperrors();
     Protocol_atom = XInternAtom(p->gdisp, "WM_PROTOCOLS", False);
     Kill_atom = XInternAtom(p->gdisp, "WM_DELETE_WINDOW", False);
     if(!p->split_window)
@@ -344,8 +352,6 @@ object *get_player(player *p, mapstruct *m) {
     op->y=EXIT_Y(m->map_object)+freearr_y[i];
   }
   p->fire_on=0,p->run_on=0;
-/*  p->face=0;
-  op->face=classarch[p->face]->faces[0]; */
   p->count=0;
   p->count_left=0;
   p->prev_cmd=' ';
@@ -360,6 +366,7 @@ object *get_player(player *p, mapstruct *m) {
 
   op->contr=p; /* this aren't yet in archetype */
   op->speed_left=0.5;
+  op->speed=1.0;
   op->direction=0;
   op->stats.wc=2;
   op->run_away = 25; /* Then we panick... */
@@ -393,7 +400,9 @@ object *get_player(player *p, mapstruct *m) {
     p->known_spells[i]= -1;
   p->nrofknownspells=0;
   p->chosen_spell = -1;
-  p->chosen_skill = -1;
+  p->ob->chosen_skill = NULL;
+  if(QUERY_FLAG(op,FLAG_READY_SKILL))
+        CLEAR_FLAG(op,FLAG_READY_SKILL); 
   draw_all_inventory(op);
   draw_all_look(op);
   return op;
@@ -1046,7 +1055,8 @@ static void fire_bow(object *op, int dir)
 		      0 : dam_bonus[op->stats.Str]) +
 			bow->stats.dam + bow->magic + arrow->magic;
   arrow->stats.wc = 20 - bow->magic - arrow->magic - op->level -
-    dex_bonus[op->stats.Dex] - thaco_bonus[op->stats.Str] - arrow->stats.wc;
+    dex_bonus[op->stats.Dex] - thaco_bonus[op->stats.Str] - arrow->stats.wc -
+    bow->stats.wc;
   
   arrow->map = op->map;
   SET_FLAG(arrow, FLAG_FLYING);
@@ -1067,6 +1077,99 @@ static void fire_bow(object *op, int dir)
   }  
 }
 
+/* this handles all hand-to-hand attacks -b.t. */
+
+void attack_hth(object *pl, int dir, char *string) {
+  char buf[MAX_BUF];
+  object *tmp, *weapon;
+  int dx=freearr_x[dir],dy=freearr_y[dir];
+
+  if(QUERY_FLAG(pl, FLAG_READY_WEAPON))
+    for(weapon=pl->inv;weapon;weapon=weapon->below) {
+	if(weapon->type!=WEAPON
+	  ||!QUERY_FLAG(weapon, FLAG_APPLIED)) continue; 
+   	CLEAR_FLAG(weapon,FLAG_APPLIED);
+  	CLEAR_FLAG(pl,FLAG_READY_WEAPON);
+	if(pl->type==PLAYER) {
+      	  new_draw_info(NDI_UNIQUE, 0,pl,"You unweild your weapon in order to attack.");
+   	  fix_player(pl);
+	  draw_stats(pl);
+	  draw_inventory(pl);
+	}
+	break;
+    }
+
+/* Note we could have more fun here. Idiots who slug walls or open
+ *	flame should take damage!, Alas, not yet implemented -bt 
+ */
+
+  for(tmp=get_map_ob(pl->map,pl->x+dx,pl->y+dy);
+      tmp;tmp=tmp->above) 
+        if(QUERY_FLAG(tmp,FLAG_ALIVE)    /* is there something to attack? */
+           || QUERY_FLAG(tmp, FLAG_CAN_ROLL)
+           || tmp->type==LOCKED_DOOR ) { 
+           
+		if(pl->type==PLAYER && tmp->type==PLAYER) /* same party, forget attack */ 
+		    if(pl->contr->party_number!=-1 && 
+                       pl->contr->party_number==tmp->contr->party_number) return; 
+
+		pl->stats.dam = hth_damage(tmp, pl);  
+
+		if(pl->type==PLAYER && pl->contr->tmp_invis) {
+        		pl->contr->tmp_invis=0;
+        		pl->invisible=0;
+        		pl->hide=0;
+        		update_object(pl);
+  		}
+
+  		if(string!=NULL && pl->type==PLAYER) {
+			sprintf(buf, string);
+  			new_draw_info_format(NDI_UNIQUE, 0,pl,"You %s %s!",buf,query_name(tmp));
+		}
+		if(attack_ob(tmp, pl) && tmp->type==PLAYER) { 
+			sprintf(buf, string);
+    			new_draw_info_format(NDI_UNIQUE, 0,tmp,"%s %s you!",query_name(pl),buf);
+		}
+               	return; 
+       }
+  if(pl->type==PLAYER) {
+    sprintf (buf, "There is nothing there to attack!");
+    new_draw_info(NDI_UNIQUE, 0,pl,buf);
+  }
+}
+
+/* hth_damage() - generalized to allow monster skill use too */
+
+int hth_damage(object *target, object *pl) {
+  int base = pl->arch->clone.stats.dam + dam_bonus[pl->stats.Str];
+  int damage = pl->chosen_skill->stats.dam * (1 + (pl->level/9));
+
+  if(damage<1)  		/* Safety - not a hth skill per se */
+ 	return base;
+  else
+  	damage += base;
+
+ /* Against some creatures the hth attack gets no special bonus.
+  * Probably left out some cases here -b.t.
+  */
+
+  if((target->level>pl->level) 
+     || QUERY_FLAG(target,FLAG_UNDEAD)
+     || QUERY_FLAG(target,FLAG_SPLITTING)
+     || QUERY_FLAG(target,FLAG_HITBACK)) { 
+         pl->attacktype=AT_PHYSICAL;
+         return damage;
+  }
+
+  damage += (((pl->level+1)/7)*pl->chosen_skill->stats.dam) + 1;
+
+  if(pl->type==PLAYER && (damage!=pl->stats.dam)) { 
+	pl->stats.dam = damage;
+	draw_stats(pl);
+  }	
+  return damage;
+}
+
 void fire(object *op,int dir) {
   object *weap=NULL;
 
@@ -1162,34 +1265,12 @@ void fire(object *op,int dir) {
 	control_golem(op->contr->golem, dir);
     return;
   case range_skill:
-    switch(op->contr->chosen_skill) {
-      case SK_STEALING:
-	steal(op, dir);
-	break;
-      case SK_LOCKPICKING:
-	pick_lock(op, dir);
-	break;
-      case SK_HIDING:
-        hide(op);
-	break;
-      case SK_JUMPING:
-	jump(op, dir); 
-	break;
-      case SK_SMITH:
-      case SK_BOWYER:
-      case SK_JEWELER:
-      case SK_ALCHEMY:
-      case SK_THAUMATURGY:
-      case SK_LITERACY:
-	skill_ident(op);
-	break;
-      case SK_BARGAINING:
-      	new_draw_info(NDI_UNIQUE, 0,op,"This skill is already in effect.");
-	break;
-      default:
-      	new_draw_info(NDI_UNIQUE, 0,op,"You have no applicable skill to use.");
-	break;
+    if(!op->chosen_skill) { 
+	if(op->type==PLAYER)
+      	    new_draw_info(NDI_UNIQUE, 0,op,"You have no applicable skill to use.");
+	return;
     }
+    (void) do_skill(op,dir);
     return;
 
 #if 0
@@ -1233,6 +1314,72 @@ void fire(object *op,int dir) {
   }
 }
 
+/* do_skill - we require a separate routine outside of fire() so as to allow monsters
+ * to utilize skills. Its also neater - b.t.
+ */
+ 
+int do_skill (object *op, int dir) {
+
+    switch(op->chosen_skill->stats.sp) {
+      case SK_STEALING:
+        steal(op, dir);
+        break;
+      case SK_LOCKPICKING:
+        pick_lock(op, dir);
+        break;
+      case SK_HIDING:
+        hide(op);
+        break;
+      case SK_JUMPING:
+        jump(op, dir);
+        break;
+      case SK_INSCRIPTION:
+        write_scroll(op);
+        break;
+      case SK_MEDITATION:
+        meditate(op);
+        break;
+      case SK_KARATE:
+        attack_hth(op,dir,"karate-chopped");
+        break;
+      case SK_WRESTLING:
+        attack_hth(op,dir,"grappled");
+        break;
+      case SK_BOXING:
+        attack_hth(op,dir,"punched");
+        break;
+      case SK_FIND_TRAPS:
+        find_traps(op);
+        break;
+      case SK_MUSIC:
+        singing(op,dir);
+        break;
+      case SK_ORATORY:
+        use_oratory(op,dir);
+        break;
+      case SK_SMITH:
+      case SK_BOWYER:
+      case SK_JEWELER:
+      case SK_ALCHEMY:
+      case SK_THAUMATURGY:
+      case SK_LITERACY:
+      case SK_DET_MAGIC:
+      case SK_DET_CURSE:
+        skill_ident(op);
+        break;
+      case SK_WOODSMAN:
+      case SK_CLIMBING:
+      case SK_BARGAINING:
+        new_draw_info(NDI_UNIQUE, 0,op,"This skill is already in effect.");
+        break;
+      default:
+        LOG(llevError,"Attempted to use unknown skill: %d\n"
+                ,op->chosen_skill->stats.dam);
+        return 0;
+    }
+    return 1;
+}
+
 /* This function is just part of a breakup from move_player.
  * It should keep the code cleaner.
  * When this is called, the players direction has been updated
@@ -1353,6 +1500,12 @@ void move_player_attack(object *op, int dir)
 	((tmp->type!=PLAYER || op->contr->party_number==-1 ||
 	op->contr->party_number!=tmp->contr->party_number))) {
 
+	  if(QUERY_FLAG(op,FLAG_READY_SKILL) && op->chosen_skill
+	     && !QUERY_FLAG(op, FLAG_READY_WEAPON))  
+		 if((op->type==PLAYER && op->contr->shoottype==range_skill)
+		    || (op->type!=PLAYER))  
+		        op->stats.dam = hth_damage(tmp,op);  
+
 	  (void) attack_ob(tmp,op);
 	  /* If attacking another player, that player gets automatic
 	   * hitback, and doesn't loose luck either.
@@ -1376,7 +1529,7 @@ void move_player_attack(object *op, int dir)
 }
 
 int move_player(object *op,int dir) {
-  int dx, dy, num1, num2;
+  int dx, dy, num1;
   int face = dir ? (dir - 1) / 2 : -1;
 
   if(op->map == NULL || op->map->in_memory != MAP_IN_MEMORY)
@@ -1391,19 +1544,20 @@ int move_player(object *op,int dir) {
   dy = freearr_y[dir];
 
 /* For Hidden players- a chance of becoming 'unhidden'
- * every time they move - bt. (thomas@nomad.astro.psu.edu) 
+ * every time they move - as we subtract off 'invisibility'
+ * from the player bt. (thomas@astro.psu.edu) 
  */ 
   if(op->hide>0) {  
-    num1=(RANDOM()%20+RANDOM()%20)/2;
-    num2=(op->stats.Dex+(op->level/5))-(op->map->difficulty + op->stats.Cha); 
-    if(num1 < num2) {
+    num1=RANDOM()%10 + op->map->difficulty;
+    if(num1>op->invisible) {
         char buf[MAX_BUF];
 	op->contr->tmp_invis=0;
         op->hide=0;
         op->invisible=0;
 	sprintf(buf,"You moved too much! You are visible!"); 
         new_draw_info(NDI_UNIQUE, 0,op,buf);
-    } 
+    } else
+        op->invisible-=num1;
   }
 
   if(op->contr->fire_on)
@@ -1475,17 +1629,18 @@ int handle_buttonpress(object *op)
 	i++;
 
       switch (i) {
-       case 0: move_player (op,8);return 1;
-       case 1: move_player (op,7);return 1;
-       case 2: move_player (op,6);return 1;
-       case 3: move_player (op,1);return 1;
-       case 5: move_player (op,5);return 1;
-       case 6: move_player (op,2);return 1;
-       case 7: move_player (op,3);return 1;
-       case 8: move_player (op,4);return 1;
+       case 0: move_player (op,8);break;
+       case 1: move_player (op,7);break;
+       case 2: move_player (op,6);break;
+       case 3: move_player (op,1);break;
+       case 5: move_player (op,5);break;
+       case 6: move_player (op,2);break;
+       case 7: move_player (op,3);break;
+       case 8: move_player (op,4);break;
       }
       if (button == 2)
 	op->contr->fire_on=0;
+      if (i>=0 && i<=8) return 1;
       return 0;
     }
     return 1;
@@ -2380,6 +2535,7 @@ void do_some_living(object *op) {
     draw_stats(op);
 /*  draw_inventory(op);   inventory hasn't changed */
     new_draw_info(NDI_UNIQUE, 0,op,"YOU HAVE DIED.");
+    save_player(op,1);
     return;
 #endif
 
