@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_rune_c =
- *   "$Id: rune.c,v 1.10 1994/12/30 08:01:47 master Exp $";
+ *   "$Id: rune.c,v 1.11 1995/07/24 22:17:08 master Exp $";
  */
 
 /*
@@ -248,15 +248,24 @@ int dispel_rune(object *op,int dir,int risk)
 	
 }
 
+/* I modified this slightly to allow greater trap detection
+ * with the detect traps skill (has_skill==1) - b.t.
+ */
 
-int trap_see(object *op,object *trap) {
+int trap_see(object *op,object *trap,int has_skill) {
   char buf[MAX_BUF];
-  int trapworth;
+  int chance,trapworth;
 
+  if(has_skill>0) 
+	chance = RANDOM()%200;
+  else
+	chance = RANDOM()%100;
+  
   /*  decide if we see the rune or not */
-  if((trap->stats.Cha==1) || ((RANDOM()%100) >
-   MIN(95,MAX(5,((int)((float) (op->map->difficulty + trap->level + trap->stats.Cha-op->level)/10.0 * 50.0))))))
-   {
+  if((trap->stats.Cha==1) || (chance >
+        MIN(95,MAX(5,((int)((float) (op->map->difficulty 
+	+ trap->level + trap->stats.Cha-op->level)/10.0 * 50.0))))))
+  {
       sprintf(buf,"You spot a %s!",trap->name);
       new_draw_info(NDI_UNIQUE, 0,op,buf);
 
@@ -264,7 +273,7 @@ int trap_see(object *op,object *trap) {
       if(trap->stats.Cha>1) add_exp(op,trapworth);  /* finding a trap awards exp */
       trap->stats.Cha=1;  /* unhide the rune/trap */
       return 1;
-   }
+  }
   return 0;
 }
 
