@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_shop_c =
- *   "$Id: shop.c,v 1.29 1995/04/15 05:01:35 master Exp master $";
+ *   "$Id: shop.c,v 1.31 1995/09/11 03:16:47 master Exp master $";
  */
 
 /*
@@ -61,7 +61,7 @@ static char *coins[] = {"platinacoin", "goldcoin", "silvercoin", NULL};
 int query_cost(object *tmp, object *who, int flag) {
   int val;
   int number;	/* used to better calculate value */
-  int charisma = who->stats.Cha;  /* used for SK_BARGAINING modification */ 
+  int charisma;
 
   if (tmp->type==MONEY) return (tmp->nrof * tmp->value);
   if (tmp->type==GEM) {
@@ -140,22 +140,24 @@ int query_cost(object *tmp, object *who, int flag) {
 	val *= number;
     }
   }
+
 /* this  modification is for merchant skill 
- * now players with readied merchant skill get 10 cha
- * more up to the limit of  modified Cha = 30.
+ * now players with readied merchant skill get 
+ * more Cha up to the limit of modified Cha = 30.
  * -b.t. thomas@nomad.astro.psu.edu 
  */
-  if(who->contr->chosen_skill == SK_BARGAINING
-	&& who!=NULL && who->type==PLAYER
-	&& who->contr->shoottype == range_skill) { 
-	charisma = who->stats.Cha + 10;
-	if(charisma>30) charisma = 30;
-  }
-  if (who!=NULL) {
-    if(flag==F_BUY)
-      val=(val*(100-cha_bonus[charisma]))/100;
-    else if (flag==F_SELL)
-      val=(val*100)/(100-cha_bonus[charisma]);
+
+  if (who!=NULL && who->type==PLAYER) { 
+      charisma = who->stats.Cha;  /* used for SK_BARGAINING modification */ 
+      if(who->contr->shoottype == range_skill && who->chosen_skill)
+         if(who->chosen_skill->stats.sp == SK_BARGAINING) { 
+	    charisma = who->stats.Cha + (who->level+2)/3;
+	    if(charisma>30) charisma = 30;
+         }
+      if(flag==F_BUY)
+          val=(val*(100-cha_bonus[charisma]))/100;
+      else if (flag==F_SELL)
+          val=(val*100)/(100-cha_bonus[charisma]);
   }
   if(val<0)
     val=1000000;
@@ -582,10 +584,10 @@ void shop_listing_more(object *op)
 void shop_listing(object *op)
 {
 	int i,j;
-	char *map_mark = (char *) calloc
-		(op->map->mapx * op->map->mapy, 1);
+	char *map_mark = (char *) malloc(op->map->mapx * op->map->mapy);
 	object	*tmp,*stack;
 
+	memset(map_mark, 0, op->map->mapx * op->map->mapy);
 	magic_mapping_mark(op, map_mark, 3);
 
 	if (op->contr->menu!=NULL) {
@@ -607,7 +609,7 @@ void shop_listing(object *op)
 		    }
 		}
 	    }
-	free (map_mark);
+	free(map_mark);
 	shop_listing_more(op);
 }
 
