@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_newspells_c =
- *   "$Id: spell_effect.c,v 1.7 1995/04/15 05:03:43 master Exp master $";
+ *   "$Id: spell_effect.c,v 1.9 1995/09/11 03:17:59 master Exp master $";
  */
 
 
@@ -674,7 +674,7 @@ int dimension_door(object *op,int dir) {
       draw(op);
       return 1;
     }
-  } else {
+  } /* if op->contr->count*/ else {
     for(dist=0;!blocks_view (op->map,op->x+freearr_x[dir]*(dist+1),
                                      op->y+freearr_y[dir]*(dist+1))&&
                !blocks_magic(op->map,op->x+freearr_x[dir]*(dist+1),
@@ -791,11 +791,13 @@ int cast_regenerate_spellpoints(object *op) {
 
 int
 cast_change_attr(object *op,int dir,int spell_type) {
-  object *tmp;
+  object *tmp = op;
   object *force;
   int i;
 
-  tmp=find_target_for_friendly_spell(op,dir);
+  /* if dir = 99 op defaults to tmp, eat_special_food() requires this. */
+  if(dir!=99)
+     tmp=find_target_for_friendly_spell(op,dir);
 
   if(tmp==NULL) return 0;
 
@@ -1265,6 +1267,7 @@ int cast_create_missile(object *op, int dir, char *stringarg)
   missile = get_archetype(missile_name);
   missile->nrof = missile_nrof;
   missile->magic = missile_plus;
+  missile->value=0;
   SET_FLAG(missile, FLAG_IDENTIFIED);
   if (!cast_create_obj(op,missile,dir) && op->type==PLAYER)
     pick_up(op, missile);
@@ -1636,11 +1639,11 @@ int cast_detection(object *op, int type) {
 
 /* Shamelessly hacked from PeterM's cast_charm code */
 /* b.t. thomas@nomad.astro.psu.edu		   */
-int cast_pacify(object *op, object *weap, archetype *arch,int spell) {
+int cast_pacify(object *op, object *weap, archetype *arch,int spellnum ) {
   int i; 
   object *tmp,*effect;
 
-  for(i=1;i<MIN(9+SP_level_strength_adjust(op,spell),SIZEOFFREE);i++) {
+  for(i=1;i<MIN(9+SP_level_strength_adjust(op,spellnum),SIZEOFFREE);i++) {
         for(tmp=get_map_ob(op->map,op->x+freearr_x[i],op->y+freearr_y[i]);
             tmp&&(!QUERY_FLAG(tmp,FLAG_MONSTER));tmp=tmp->above);
         if(!tmp) continue;
@@ -1670,20 +1673,20 @@ int cast_pacify(object *op, object *weap, archetype *arch,int spell) {
  * (based on create bomb code)
  */
 
-int summon_fog(object *op, int dir,int spell) { 
+int summon_fog(object *op, int dir,int spellnum) { 
   object *tmp;
   int i,dx=op->x+freearr_x[dir],dy=op->y+freearr_y[dir];
 
-  if (!spellarch[spell])
+  if (!spellarch[spellnum])
     return 0;
 
-  for(i=1;i<MIN(2+SP_level_strength_adjust(op,spell),SIZEOFFREE);i++) {
+  for(i=1;i<MIN(2+SP_level_strength_adjust(op,spellnum),SIZEOFFREE);i++) {
 
      if(wall(op->map,dx,dy)) {
         new_draw_info(NDI_UNIQUE, 0,op,"There is something in the way.");
         return 0;
      }
-     tmp=get_archetype(spellarch[spell]->name);
+     tmp=get_archetype(spellarch[spellnum]->name);
      tmp->x=dx,tmp->y=dy;	/* all fog starts in 1 place */ 
 #ifdef WALL_CREDIT              /* does someone get exp for the kills? */ 
      set_owner(tmp,op);		/* note however, that after 'fog' moves */ 
@@ -1796,7 +1799,8 @@ int cast_transfer(object *op,int dir) {
             new_draw_info(NDI_UNIQUE, 0,plyr,"Your head explodes!");
             fire_arch (plyr, 0, spellarch[SP_L_FIREBALL], SP_L_FIREBALL, 0);
                 /* Explodes a large fireball centered at player */
-            hit_player(plyr, 9999, op, AT_PHYSICAL);
+/*            hit_player(plyr, 9999, op, AT_PHYSICAL);*/
+	    plyr->stats.sp = 2*maxsp;
 
         }
         else if(sp>=maxsp*1.88)
@@ -1905,11 +1909,11 @@ int summon_hostile_monsters(object *op,int n,char *monstername){
     monster of the caster.  Monsters larger than 1 square
     are uncharmeable right now.  */
 
-int cast_charm(object *op, archetype *arch,int spell) {
+int cast_charm(object *op, archetype *arch,int spellnum) {
   int i;
   object *tmp,*effect;
   
-  for(i=1;i<MIN(9+SP_level_strength_adjust(op,spell),SIZEOFFREE);i++) {
+  for(i=1;i<MIN(9+SP_level_strength_adjust(op,spellnum),SIZEOFFREE);i++) {
 	for(tmp=get_map_ob(op->map,op->x+freearr_x[i],op->y+freearr_y[i]);
 	    tmp&&(!QUERY_FLAG(tmp,FLAG_MONSTER));tmp=tmp->above);
 	if(!tmp) continue;
