@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_spells_c =
- *   "$Id: spell_util.c,v 1.7 1995/04/15 05:04:20 master Exp master $";
+ *   "$Id: spell_util.c,v 1.9 1995/09/11 03:18:57 master Exp master $";
  */
 
 /*
@@ -43,7 +43,10 @@ extern int sys_nerr;
 #endif
 
 char *range_name[range_size] = {
-  "none", "bow", "magic", "wand", "rod", "scroll", "horn", "steal"
+  "none", "bow", "magic", "wand", "rod", "scroll", "horn"
+#ifdef ALLOW_SKILLS
+	,"steal"
+#endif
 };
 
 void init_spells() {
@@ -131,7 +134,7 @@ int cast_spell(object *op,object *caster,int dir,int type,int ability,SpellTypeF
   spell *s=find_spell(type);
   int success=0,bonus;
   int duration=SP_PARAMETERS[type].bdur;  /*  get the base duration */
-  object casting_object;
+  object casting_object, *orig_op=op;
 
   if(item!=spellNormal&&caster!=op) {
 	reset_object(&casting_object);
@@ -345,7 +348,10 @@ if (item == spellNormal && !ability ){
     success = summon_pet(op,dir, item);
     break;
   case SP_D_DOOR:
-    success = dimension_door(op,dir);
+    /* dimension door needs the actual caster, because that is what is
+     * moved.
+     */
+    success = dimension_door(orig_op,dir);
     break;
   case SP_CHAOS_POOL:
   case SP_COUNTERWALL:
@@ -634,7 +640,7 @@ int cast_create_obj(object *op,object *new_op, int dir)
   return dir;
 }
 
-int summon_monster(object *op,int dir,archetype *at,int spell) {
+int summon_monster(object *op,int dir,archetype *at,int spellnum) {
   object *tmp;
   if(op->type==PLAYER)
     if(op->contr->golem!=NULL&&!QUERY_FLAG(op->contr->golem,FLAG_FREED)) {
@@ -672,13 +678,13 @@ int summon_monster(object *op,int dir,archetype *at,int spell) {
     SET_FLAG(tmp, FLAG_MONSTER);
   }
   /*  This sets the level dependencies on dam and hp for monsters */
-  tmp->stats.hp = SP_PARAMETERS[spell].bdur +
-			 10 * SP_level_strength_adjust(op,spell);
-  tmp->stats.dam= SP_PARAMETERS[spell].bdam +
-			 2* SP_level_dam_adjust(op,spell);
+  tmp->stats.hp = SP_PARAMETERS[spellnum].bdur +
+			 10 * SP_level_strength_adjust(op,spellnum);
+  tmp->stats.dam= SP_PARAMETERS[spellnum].bdam +
+			 2* SP_level_dam_adjust(op,spellnum);
   if(tmp->stats.dam<0) tmp->stats.dam=127;  /*seen this go negative!*/
  /*  make experience increase in proportion to the strength of the summoned creature. */
-  tmp->stats.exp *= SP_level_spellpoint_cost(op,spell)/spells[spell].sp;
+  tmp->stats.exp *= SP_level_spellpoint_cost(op,spellnum)/spells[spellnum].sp;
   tmp->speed_left= -1;
   tmp->x=op->x+freearr_x[dir],tmp->y=op->y+freearr_y[dir];
   tmp->direction=dir;
@@ -1216,9 +1222,11 @@ spells such as heal or protection or armour  */
 object *find_target_for_friendly_spell(object *op,int dir) 
 { object *tmp;
   if(op->type!=PLAYER&&op->type!=RUNE) {
-    if(op->owner&&QUERY_FLAG(op->owner,FLAG_MONSTER)) tmp=op->owner;
-    else
-    tmp=op;
+    tmp=get_owner(op);
+    /* If the owner does not exist, or is not a monster, than apply the spell
+     * to the caster.
+     */
+    if(!tmp || !QUERY_FLAG(tmp,FLAG_MONSTER)) tmp=op;
   }
   else
     for(tmp=get_map_ob(op->map,op->x+freearr_x[dir],op->y+freearr_y[dir]);
