@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_time_c =
- *    "$Id: time.c,v 1.28 1995/04/15 05:05:19 master Exp master $";
+ *    "$Id: time.c,v 1.29 1995/09/11 03:23:21 master Exp master $";
  */
 
 /*
@@ -509,7 +509,7 @@ void change_object(object *op) { /* Doesn`t handle linked objs yet */
   object *tmp;
   int i,j;
   if(op->other_arch==NULL) {
-    LOG(llevError,"Change object without other_arch error.\n");
+    LOG(llevError,"Change object (%s) without other_arch error.\n", op->name);
     return;
   }
   remove_ob(op);
