@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_xio_c =
- *   "$Id: xio.c,v 1.39 1995/04/15 05:05:54 master Exp master $";
+ *   "$Id: xio.c,v 1.41 1995/09/11 03:23:54 master Exp master $";
  */
 
 /*
@@ -78,6 +78,7 @@ int IOerrors(Display *d) {
       break;
   if(pl==NULL)
     return 0;
+  save_player(pl->ob, 1);
   LOG(llevError,"Player %s lost the display.\n",pl->name);
   (void) sprintf(buf,"%s lost connection.",pl->name);
   remove_lock(pl);
@@ -101,9 +102,13 @@ int IOerrors(Display *d) {
  * If in a server-mode, I assume a shell-script is restarting it.
  * Thus I exit if I can, since some variables can be messed up by the
  * longjmp() below.
+ *
+ * If we are in server mode, don't exit.  This way, maps don't reset.
  */
-  if(first_player==NULL)
+  if(first_player==NULL && server_mode !=SERVER_ENABLED) {
+    LOG(llevError,"Only 1 player - exiting the program.\n");
     exit(0);
+  }
   new_draw_info(NDI_UNIQUE | NDI_ALL, 5, NULL, buf);
 
 #ifdef LONGJUMP
@@ -182,20 +187,19 @@ int get_root_display(player *p, char *display) {
   p->roothint.max_height=p->roothint.min_height=p->roothint.height;
   p->roothint.flags=PPosition | PSize;
   if(!p->split_window) {
-#if 0
-    p->win_root=XCreateWindow(p->gdisp,DefaultRootWindow(p->gdisp),
-	p->roothint.x,p->roothint.y,p->roothint.width,p->roothint.height,2,
-	CopyFromParent,CopyFromParent,CopyFromParent,0,&attr);
-#else
     p->win_root=XCreateSimpleWindow(p->gdisp,DefaultRootWindow(p->gdisp),
         p->roothint.x,p->roothint.y,p->roothint.width,p->roothint.height,2,
         p->gbackground,p->gforeground);
-#endif
     p->iscolor=allocate_colors(p->gdisp, p->win_root, p->gscreen,
 	&p->colormap, p->discolor);
     if (p->iscolor){
-       p->gforeground=p->discolor[0].pixel;
-       p->gbackground=p->discolor[8].pixel;
+	p->gforeground=p->discolor[0].pixel;
+	p->gbackground=p->discolor[8].pixel;
+	/* We need to set this here - while we pretend to set it in the
+	 * XCreateSimpleWindow above, we actually haven't set the colors yet.
+	 */
+	XSetWindowBackground(p->gdisp, p->win_root, p->gforeground);
+	XSetWindowBorder(p->gdisp, p->win_root, p->gbackground);
     }
     p->pixmap=XCreateBitmapFromData(p->gdisp,p->win_root,
           (_Xconst char *) crossfire_bits,
@@ -242,12 +246,17 @@ int get_game_display(player *p,char *display) {
     p->iscolor=allocate_colors(p->gdisp, p->win_game, p->gscreen,
 	&p->colormap, p->discolor);
     if (p->iscolor){
-       p->gforeground=p->discolor[0].pixel;
-       p->gbackground=p->discolor[8].pixel;
+	p->gforeground=p->discolor[0].pixel;
+	p->gbackground=p->discolor[8].pixel;
+	/* We need to set this here - while we pretend to set it in the
+	 * XCreateSimpleWindow above, we actually haven't set the colors yet.
+	 */
+	XSetWindowBackground(p->gdisp, p->win_game, p->gforeground);
+	XSetWindowBorder(p->gdisp, p->win_game, p->gbackground);
     }
-  } else {
+  } else if (p->iscolor) 
     XSetWindowColormap(p->gdisp, p->win_game, p->colormap);
-  }
+
   XSetStandardProperties(p->gdisp,p->win_game,"Crossfire",name,
                          p->pixmap,gargv,gargc, &(p->gamehint));
 
@@ -308,7 +317,8 @@ int get_info_display(player *p,char *name) {
       p->split_window?DefaultRootWindow(p->gdisp):p->win_root,
       p->infohint.x,p->infohint.y,p->infohint.width,p->infohint.height,2,
       p->gforeground,p->gbackground);
-  XSetWindowColormap(p->gdisp, p->win_info, p->colormap);
+  if (p->iscolor)
+    XSetWindowColormap(p->gdisp, p->win_info, p->colormap);
   p->pixmap=XCreateBitmapFromData(p->gdisp,p->win_info,
           (_Xconst char *) crossfire_bits,
 	  (unsigned int) crossfire_width, (unsigned int)crossfire_height);
@@ -461,7 +471,8 @@ int get_message_display(player *p,char *name) { /* Misc-window */
       p->split_window?DefaultRootWindow(p->gdisp):p->win_root,
       p->messagehint.x,p->messagehint.y,p->messagehint.width,
       p->messagehint.height,2,p->gforeground,p->gbackground);
-  XSetWindowColormap(p->gdisp, p->win_message, p->colormap);
+  if (p->iscolor)
+    XSetWindowColormap(p->gdisp, p->win_message, p->colormap);
   p->pixmap=XCreateBitmapFromData(p->gdisp,p->win_message,
           (_Xconst char *) crossfire_bits,
 	  (unsigned int) crossfire_width, (unsigned int)crossfire_height);
@@ -492,7 +503,8 @@ int get_inv_display(player *p,char *name) {
       p->split_window?DefaultRootWindow(p->gdisp):p->win_root,
       p->invhint.x,p->invhint.y,p->invhint.width,p->invhint.height,2,
       p->gforeground,p->gbackground);
-  XSetWindowColormap(p->gdisp, p->win_inv, p->colormap);
+  if (p->iscolor)
+    XSetWindowColormap(p->gdisp, p->win_inv, p->colormap);
   p->pixmap=XCreateBitmapFromData(p->gdisp,p->win_inv,
           (_Xconst char *) crossfire_bits,
 	  (unsigned int) crossfire_width, (unsigned int)crossfire_height);
@@ -539,7 +551,8 @@ int get_look_display(player *p,char *name) {
       p->split_window?DefaultRootWindow(p->gdisp):p->win_root,
       p->lookhint.x,p->lookhint.y,p->lookhint.width,p->lookhint.height,2,
       p->gforeground,p->gbackground);
-  XSetWindowColormap(p->gdisp, p->win_look, p->colormap);
+  if (p->iscolor)
+    XSetWindowColormap(p->gdisp, p->win_look, p->colormap);
   p->pixmap=XCreateBitmapFromData(p->gdisp,p->win_look,
           (_Xconst char *) crossfire_bits,
 	  (unsigned int) crossfire_width, (unsigned int)crossfire_height);
@@ -576,7 +589,8 @@ int get_stats_display(player *p,char *name) {
       p->split_window?DefaultRootWindow(p->gdisp):p->win_root,
       p->stathint.x,p->stathint.y,p->stathint.width,p->stathint.height,2,
       p->gforeground,p->gbackground);
-  XSetWindowColormap(p->gdisp, p->win_stats, p->colormap);
+  if (p->iscolor)
+    XSetWindowColormap(p->gdisp, p->win_stats, p->colormap);
   p->pixmap=XCreateBitmapFromData(p->gdisp,p->win_stats,
           (_Xconst char *) crossfire_bits,
 	  (unsigned int) crossfire_width, (unsigned int)crossfire_height);
@@ -676,8 +690,8 @@ void rangetostring(object *pl,char *obuf)
     }
     break;
    case range_skill:
-       sprintf(obuf,"Skill: %s", pl->contr->chosen_skill!=-1 ?
-		skills[pl->contr->chosen_skill].name : "none");
+       sprintf(obuf,"Skill: %s", pl->chosen_skill!=NULL ?
+		skills[pl->chosen_skill->stats.sp].name : "none");
     break;
    default:
     strcpy(obuf,"Range: illegal");
@@ -1168,7 +1182,7 @@ void draw_look(object *pl) {
        * previous item name printed in the window.
        */
 
-      if(strlen(buf)<p->look_chars)
+      if((sint16)strlen(buf)<p->look_chars)
         memset((void *)cp,' ',p->look_chars-strlen(buf));
       buf[p->look_chars]='\0';
     } else
@@ -1955,11 +1969,11 @@ void magic_mapping_mark_recursive(object *pl, char *map_mark, int px, int py);
 void draw_map(object *pl) 
 {
   int res,x,y;
-  char *map_mark = (char *) calloc(pl->map->mapx * pl->map->mapy, 1);
+  char *map_mark = (char *) malloc(pl->map->mapx * pl->map->mapy);
   int xmin = pl->map->mapx, xmax = 0, ymin = pl->map->mapy, ymax = 0;
   XWindowAttributes win_info;
 
-
+  memset(map_mark, 0, pl->map->mapx * pl->map->mapy);
   if (pl->type == PLAYER && pl->contr->eric_server > 0) {
     esrv_foo(pl->contr->eric_server,"draw_map");
     return;
